# encoding: UHC
# This file is encoded in UHC.
die "This file is not encoded in UHC.\n" if q{‚ } ne "\x82\xa0";

use strict;
use Char;
print "1..18\n";

my $__FILE__ = __FILE__;

if ('A' =~ m?(A)?) {
    if ($1 eq 'A') {
        print qq{ok - 1 'A' =~ m?(A)? $^X $__FILE__\n};
    }
    else {
        print qq{not ok - 1 'A' =~ m?(A)? $^X $__FILE__\n};
    }
}
else {
    print qq{not ok - 1 'A' =~ m?(A)? $^X $__FILE__\n};
}

if ('A' =~ m?(A)?b) {
    if ($1 eq 'A') {
        print qq{ok - 2 'A' =~ m?(A)?b $^X $__FILE__\n};
    }
    else {
        print qq{not ok - 2 'A' =~ m?(A)?b $^X $__FILE__\n};
    }
}
else {
    print qq{not ok - 2 'A' =~ m?(A)?b $^X $__FILE__\n};
}

if ('A' =~ m?(a)?i) {
    if ($1 eq 'A') {
        print qq{ok - 3 'A' =~ m?(a)?i $^X $__FILE__\n};
    }
    else {
        print qq{not ok - 3 'A' =~ m?(a)?i $^X $__FILE__\n};
    }
}
else {
    print qq{not ok - 3 'A' =~ m?(a)?i $^X $__FILE__\n};
}

if ('A' =~ m?(a)?ib) {
    if ($1 eq 'A') {
        print qq{ok - 4 'A' =~ m?(a)?ib $^X $__FILE__\n};
    }
    else {
        print qq{not ok - 4 'A' =~ m?(a)?ib $^X $__FILE__\n};
    }
}
else {
    print qq{not ok - 4 'A' =~ m?(a)?ib $^X $__FILE__\n};
}

if ('a' =~ m?(a)?i) {
    if ($1 eq 'a') {
        print qq{ok - 5 'a' =~ m?(a)?i $^X $__FILE__\n};
    }
    else {
        print qq{not ok - 5 'a' =~ m?(a)?i $^X $__FILE__\n};
    }
}
else {
    print qq{not ok - 5 'a' =~ m?(a)?i $^X $__FILE__\n};
}

if ('a' =~ m?(a)?ib) {
    if ($1 eq 'a') {
        print qq{ok - 6 'a' =~ m?(a)?ib $^X $__FILE__\n};
    }
    else {
        print qq{not ok - 6 'a' =~ m?(a)?ib $^X $__FILE__\n};
    }
}
else {
    print qq{not ok - 6 'a' =~ m?(a)?ib $^X $__FILE__\n};
}

if ('ƒA' =~ m?(A)?b) {
    if ($1 eq 'A') {
        print qq{ok - 7 'ƒA' =~ m?(A)?b $^X $__FILE__\n};
    }
    else {
        print qq{not ok - 7 'ƒA' =~ m?(A)?b $^X $__FILE__\n};
    }
}
else {
    print qq{not ok - 7 'ƒA' =~ m?(A)?b $^X $__FILE__\n};
}

if ('ƒA' =~ m?(A)?ib) {
    if ($1 eq 'A') {
        print qq{ok - 8 'ƒA' =~ m?(A)?ib $^X $__FILE__\n};
    }
    else {
        print qq{not ok - 8 'ƒA' =~ m?(A)?ib $^X $__FILE__\n};
    }
}
else {
    print qq{not ok - 8 'ƒA' =~ m?(A)?ib $^X $__FILE__\n};
}

if ('ƒA' =~ m?(a)?ib) {
    if ($1 eq 'A') {
        print qq{ok - 9 'ƒA' =~ m?(a)?ib $^X $__FILE__\n};
    }
    else {
        print qq{not ok - 9 'ƒA' =~ m?(a)?ib $^X $__FILE__\n};
    }
}
else {
    print qq{not ok - 9 'ƒA' =~ m?(a)?ib $^X $__FILE__\n};
}

if ('ƒa' =~ m?(A)?ib) {
    if ($1 eq 'a') {
        print qq{ok - 10 'ƒa' =~ m?(A)?ib $^X $__FILE__\n};
    }
    else {
        print qq{not ok - 10 'ƒa' =~ m?(A)?ib $^X $__FILE__\n};
    }
}
else {
    print qq{not ok - 10 'ƒa' =~ m?(A)?ib $^X $__FILE__\n};
}

if ('ƒa' =~ m?(a)?b) {
    if ($1 eq 'a') {
        print qq{ok - 11 'ƒa' =~ m?(a)?b $^X $__FILE__\n};
    }
    else {
        print qq{not ok - 11 'ƒa' =~ m?(a)?b $^X $__FILE__\n};
    }
}
else {
    print qq{not ok - 11 'ƒa' =~ m?(a)?b $^X $__FILE__\n};
}

if ('ƒa' =~ m?(a)?ib) {
    if ($1 eq 'a') {
        print qq{ok - 12 'ƒa' =~ m?(a)?ib $^X $__FILE__\n};
    }
    else {
        print qq{not ok - 12 'ƒa' =~ m?(a)?ib $^X $__FILE__\n};
    }
}
else {
    print qq{not ok - 12 'ƒa' =~ m?(a)?ib $^X $__FILE__\n};
}

if ('ƒƒA' =~ m?(ƒA)?b) {
    if ($1 eq 'ƒA') {
        print qq{ok - 13 'ƒƒA' =~ m?(ƒA)?b $^X $__FILE__\n};
    }
    else {
        print qq{not ok - 13 'ƒƒA' =~ m?(ƒA)?b $^X $__FILE__\n};
    }
}
else {
    print qq{not ok - 13 'ƒƒA' =~ m?(ƒA)?b $^X $__FILE__\n};
}

if ('ƒƒA' =~ m?(ƒA)?ib) {
    if ($1 eq 'ƒA') {
        print qq{ok - 14 'ƒƒA' =~ m?(ƒA)?ib $^X $__FILE__\n};
    }
    else {
        print qq{not ok - 14 'ƒƒA' =~ m?(ƒA)?ib $^X $__FILE__\n};
    }
}
else {
    print qq{not ok - 14 'ƒƒA' =~ m?(ƒA)?ib $^X $__FILE__\n};
}

if ('ƒƒA' =~ m?(ƒa)?ib) {
    if ($1 eq 'ƒA') {
        print qq{ok - 15 'ƒƒA' =~ m?(ƒa)?ib $^X $__FILE__\n};
    }
    else {
        print qq{not ok - 15 'ƒƒA' =~ m?(ƒa)?ib $^X $__FILE__\n};
    }
}
else {
    print qq{not ok - 15 'ƒƒA' =~ m?(ƒa)?ib $^X $__FILE__\n};
}

if ('ƒƒa' =~ m?(ƒA)?ib) {
    if ($1 eq 'ƒa') {
        print qq{ok - 16 'ƒƒa' =~ m?(ƒA)?ib $^X $__FILE__\n};
    }
    else {
        print qq{not ok - 16 'ƒƒa' =~ m?(ƒA)?ib $^X $__FILE__\n};
    }
}
else {
    print qq{not ok - 16 'ƒƒa' =~ m?(ƒA)?ib $^X $__FILE__\n};
}

if ('ƒƒa' =~ m?(ƒa)?b) {
    if ($1 eq 'ƒa') {
        print qq{ok - 17 'ƒƒa' =~ m?(ƒa)?b $^X $__FILE__\n};
    }
    else {
        print qq{not ok - 17 'ƒƒa' =~ m?(ƒa)?b $^X $__FILE__\n};
    }
}
else {
    print qq{not ok - 17 'ƒƒa' =~ m?(ƒa)?b $^X $__FILE__\n};
}

if ('ƒƒa' =~ m?(ƒa)?ib) {
    if ($1 eq 'ƒa') {
        print qq{ok - 18 'ƒƒa' =~ m?(ƒa)?ib $^X $__FILE__\n};
    }
    else {
        print qq{not ok - 18 'ƒƒa' =~ m?(ƒa)?ib $^X $__FILE__\n};
    }
}
else {
    print qq{not ok - 18 'ƒƒa' =~ m?(ƒa)?ib $^X $__FILE__\n};
}

__END__

