# encoding: Big5Plus
# This file is encoded in Big5Plus.
die "This file is not encoded in Big5Plus.\n" if q{あ} ne "\x82\xa0";

use Char;
print "1..1\n";

my $__FILE__ = __FILE__;

$a = "ソアア";
if ($a =~ s/^ソ//) {
    print qq{ok - 1 "ソアア" =~ s/^ソ// $^X $__FILE__\n};
}
else {
    print qq{not ok - 1 "ソアア" =~ s/^ソ// $^X $__FILE__\n};
}

__END__
