# encoding: USASCII
use strict;

eval q{
    use Test::Pod 1.48 tests => 2;
};
if (not $@) {
    pod_file_ok('lib/Char.pm');
    pod_file_ok('README2ND/Sjis/JA.pod');
}
else {
    print "1..2\n";
    print "ok 1 - SKIP POD test\n";
    print "ok 2 - SKIP POD test\n";
}

__END__
