# encoding: Arabic
# This file is encoded in Arabic.
die "This file is not encoded in Arabic.\n" if q{‚ } ne "\x82\xa0";

use Char;
print "1..6\n";

my $__FILE__ = __FILE__;

if ('ƒAABC DEF GHI' =~ /\bABC/) {
    print "not ok - 1 $^X $__FILE__ ('ƒAABC DEF GHI' =~ /\\bABC/)\n";
}
else {
    print "ok - 1 $^X $__FILE__ ('ƒAABC DEF GHI' =~ /\\bABC/)\n";
}

if ('ƒAABC DEF GHI' =~ /\bDEF/) {
    print "ok - 2 $^X $__FILE__ ('ƒAABC DEF GHI' =~ /\\bDEF/)\n";
}
else {
    print "not ok - 2 $^X $__FILE__ ('ƒAABC DEF GHI' =~ /\\bDEF/)\n";
}

if ('ƒAABC DEF GHI' =~ /\bGHI/) {
    print "ok - 3 $^X $__FILE__ ('ƒAABC DEF GHI' =~ /\\bGHI/)\n";
}
else {
    print "not ok - 3 $^X $__FILE__ ('ƒAABC DEF GHI' =~ /\\bGHI/)\n";
}

if ('ƒAABC DEF GHI' =~ /ABC\b/) {
    print "ok - 4 $^X $__FILE__ ('ƒAABC DEF GHI' =~ /ABC\\b/)\n";
}
else {
    print "not ok - 4 $^X $__FILE__ ('ƒAABC DEF GHI' =~ /ABC\\b/)\n";
}

if ('ƒAABC DEF GHI' =~ /DEF\b/) {
    print "ok - 5 $^X $__FILE__ ('ƒAABC DEF GHI' =~ /DEF\\b/)\n";
}
else {
    print "not ok - 5 $^X $__FILE__ ('ƒAABC DEF GHI' =~ /DEF\\b/)\n";
}

if ('ƒAABC DEF GHI' =~ /GHI\b/) {
    print "ok - 6 $^X $__FILE__ ('ƒAABC DEF GHI' =~ /GHI\\b/)\n";
}
else {
    print "not ok - 6 $^X $__FILE__ ('ƒAABC DEF GHI' =~ /GHI\\b/)\n";
}

__END__
