# encoding: HP15
# This file is encoded in HP-15.
die "This file is not encoded in HP-15.\n" if q{‚ } ne "\x82\xa0";

use Char;
print "1..2\n";

my $__FILE__ = __FILE__;

if (Char::ord('‚ ') == 0x82A0) {
    print qq{ok - 1 Char::ord('‚ ') == 0x82A0 $^X $__FILE__\n};
}
else {
    print qq{not ok - 1 Char::ord('‚ ') == 0x82A0 $^X $__FILE__\n};
}

$_ = '‚¢';
if (Char::ord == 0x82A2) {
    print qq{ok - 2 \$_ = '‚¢'; Char::ord() == 0x82A2 $^X $__FILE__\n};
}
else {
    print qq{not ok - 2 \$_ = '‚¢'; Char::ord() == 0x82A2 $^X $__FILE__\n};
}

__END__
